<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation>Un cliente Jabber/XMPP simple e amigable</translation>
    </message>
    <message>
        <source>License:</source>
        <translation>Licenza:</translation>
    </message>
    <message>
        <source>View source code online</source>
        <translation>Ver código fonte en liña</translation>
    </message>
    <message>
        <source>Report problems</source>
        <translation>Informar de problemas</translation>
    </message>
</context>
<context>
    <name>AccountSecurity</name>
    <message>
        <source>Account Security</source>
        <translation>Seguridade da conta</translation>
    </message>
    <message>
        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
        <translation>Permitir engadir novos dispositivos usando un código QR, pero non mostrar o contrasinal como texto. Esta acción non ten volta, así que recomendamos gardar o contrasinal antes de utilizalo.</translation>
    </message>
    <message>
        <source>Disable showing the password</source>
        <translation>Desactivar mostrar o contrasinal</translation>
    </message>
    <message>
        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
        <translation>Non mostrar o contrasinal de ningún xeito. Esta acción non ten volta atrás.</translation>
    </message>
    <message>
        <source>Disable showing the QR-Code and password</source>
        <translation>Desactivar mostrar o código QR e o contrasinal</translation>
    </message>
</context>
<context>
    <name>AccountTransferPage</name>
    <message>
        <source>Transfer account to another device</source>
        <translation>Transferir conta a outro dispositivo</translation>
    </message>
    <message>
        <source>Scan the QR code or enter the credentials as text on another device to log in on it.

Attention:
Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
        <translation>Escanear código QR ou escribir as credenciais como texto noutro dispositivo para conectar nel.

Atención:
Nunca lle mostres este código QR a ninguén. Permitiríalle acceso sen límite á túa conta!</translation>
    </message>
    <message>
        <source>Chat address:</source>
        <translation>Enderezo da conversa:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contrasinal:</translation>
    </message>
    <message>
        <source>Hide QR code</source>
        <translation>Agochar código QR</translation>
    </message>
    <message>
        <source>Show as QR code</source>
        <translation>Mostrar como código QR</translation>
    </message>
    <message>
        <source>Hide text</source>
        <translation>Agochar texto</translation>
    </message>
    <message>
        <source>Show as text</source>
        <translation>Mostrar como texto</translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>Change password</source>
        <translation>Cambiar contrasinal</translation>
    </message>
    <message>
        <source>Current password:</source>
        <translation>Contrasinal actual:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Novo contrasinal:</translation>
    </message>
    <message>
        <source>New password (repeat):</source>
        <translation>Novo contrasinal (repita):</translation>
    </message>
    <message>
        <source>New passwords do not match.</source>
        <translation>Os contrasinais non concordan.</translation>
    </message>
    <message>
        <source>Current password is invalid.</source>
        <translation>O contrasinal actual non é correcto.</translation>
    </message>
    <message>
        <source>You need to be connected to change your password.</source>
        <translation>Precisa estar conectada para cambiar o contrasinal.</translation>
    </message>
    <message>
        <source>After changing your password, you will need to reenter it on all your other devices.</source>
        <translation>Tras cambiar o contrasinal, debes volver a introducila en todolos outros dispositivos.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Cambiar</translation>
    </message>
</context>
<context>
    <name>ChatMessage</name>
    <message>
        <source>Copy Message</source>
        <translation type="vanished">Copiar Mensaxe</translation>
    </message>
    <message>
        <source>Edit Message</source>
        <translation type="vanished">Editar Mensaxe</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation>Spoiler</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descargar</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="vanished">Copiar URL de descarga</translation>
    </message>
    <message>
        <source>Quote</source>
        <translation type="vanished">Citar</translation>
    </message>
</context>
<context>
    <name>ChatMessageContextMenu</name>
    <message>
        <source>Copy message</source>
        <translation>Copiar mensaxe</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation>Editar mensaxe</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation>Copiar URL de descarga</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation>Citar mensaxe</translation>
    </message>
</context>
<context>
    <name>ChatPage</name>
    <message>
        <source>Compose message</source>
        <translation>Redactar mensaxe</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Imaxe</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Vídeo</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Son</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="vanished">Documento</translation>
    </message>
    <message>
        <source>Other file</source>
        <translation type="vanished">Outros ficheiros</translation>
    </message>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Escoller ficheiro</translation>
    </message>
    <message>
        <source>Send a spoiler message</source>
        <translation>Enviar mensaxe spoiler</translation>
    </message>
    <message>
        <source>Spoiler hint</source>
        <translation>Aviso Spoiler</translation>
    </message>
    <message>
        <source>Unmute notifications</source>
        <translation>Restaurar notificacións</translation>
    </message>
    <message>
        <source>Mute notifications</source>
        <translation>Acalar notificacións</translation>
    </message>
    <message>
        <source>View profile</source>
        <translation>Ver perfil</translation>
    </message>
    <message>
        <source>Multimedia settings</source>
        <translation type="vanished">Axustes multimedia</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Pechar</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Buscar arriba</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Buscar abaixo</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Todos os ficheiros</translation>
    </message>
</context>
<context>
    <name>ClientWorker</name>
    <message>
        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
        <translation>A túa conta non se pode eliminar do servidor. Así, tampouco foi eliminada desta app: %1</translation>
    </message>
</context>
<context>
    <name>CommonEncoderSettings</name>
    <message>
        <source>Very low</source>
        <translation>Moi baixo</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baixo</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alto</translation>
    </message>
    <message>
        <source>Very high</source>
        <translation>Moi alto</translation>
    </message>
    <message>
        <source>Constant quality</source>
        <translation>Calidade constante</translation>
    </message>
    <message>
        <source>Constant bit rate</source>
        <translation>Taxa de bits constante</translation>
    </message>
    <message>
        <source>Average bit rate</source>
        <translation>Taxa de bits medio</translation>
    </message>
    <message>
        <source>Two pass</source>
        <translation>Dúas pasadas</translation>
    </message>
</context>
<context>
    <name>ConfirmationPage</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DisablePasswordDisplay</name>
    <message>
        <source>Remove password completely</source>
        <translation>Eliminar contrasinal completamente</translation>
    </message>
    <message>
        <source>Your password will not be included in the QR code anymore.
You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation>O teu contrasinal xa non se vai incluír no código QR.
Non poderás conectar a través do código QR sen escribir o contrasinal porque esta acción non ten volta atrás!
Asegúrate de que tes unha copia de apoio se queres usar a conta posteriormente.</translation>
    </message>
    <message>
        <source>Remove password</source>
        <translation>Eliminar contrasinal</translation>
    </message>
</context>
<context>
    <name>DisablePlainTextPasswordDisplay</name>
    <message>
        <source>Do not show password as text</source>
        <translation>Non mostrar o contrasinal como texto</translation>
    </message>
    <message>
        <source>Your password will not be shown as text anymore.
You won&apos;t be able to see your password as text again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation>O teu contrasinal non se mostrará como texto nunca máis.
Non poderás ver o teu contrasinal como texto porque esta acción non ten volta atrás!
Asegúrate de ter unha copia de apoio se queres usar a túa conta máis adiante.</translation>
    </message>
    <message>
        <source>Do not show password</source>
        <translation>Non mostrar contrasinal</translation>
    </message>
</context>
<context>
    <name>DownloadJob</name>
    <message>
        <source>Could not save file: %1</source>
        <translation>Non se gardou o ficheiro: %1</translation>
    </message>
    <message>
        <source>Download failed: %1</source>
        <translation>Fallou a descarga: %1</translation>
    </message>
</context>
<context>
    <name>EmojiPicker</name>
    <message>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>People</source>
        <translation>Xente</translation>
    </message>
    <message>
        <source>Nature</source>
        <translation>Natureza</translation>
    </message>
    <message>
        <source>Food</source>
        <translation>Comida</translation>
    </message>
    <message>
        <source>Activity</source>
        <translation>Actividade</translation>
    </message>
    <message>
        <source>Travel</source>
        <translation>Viaxes</translation>
    </message>
    <message>
        <source>Objects</source>
        <translation>Obxetos</translation>
    </message>
    <message>
        <source>Symbols</source>
        <translation>Símbolos</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Bandeiras</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Search emoji</source>
        <translation>Buscar emoji</translation>
    </message>
</context>
<context>
    <name>EmptyChatPage</name>
    <message>
        <source>Please select a chat to start messaging</source>
        <translation>Por favor, escolla unha conversa para comezar</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Escoller ficheiro</translation>
    </message>
</context>
<context>
    <name>FileChooserMobile</name>
    <message>
        <source>Go to parent folder</source>
        <translation type="vanished">Ir ao cartafol superior</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Pechar</translation>
    </message>
</context>
<context>
    <name>GlobalDrawer</name>
    <message>
        <source>Log out</source>
        <translation type="vanished">Desconectar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>Invite friends</source>
        <translation>Convidar amizades</translation>
    </message>
    <message>
        <source>Invitation link copied to clipboard</source>
        <translation>Ligazón do convite copiada</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Desconectada</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Conectada</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Conectando…</translation>
    </message>
    <message>
        <source>Switch device</source>
        <translation>Cambiar de dispositivo</translation>
    </message>
</context>
<context>
    <name>Kaidan</name>
    <message>
        <source>The link will be opened after you have connected.</source>
        <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
        <translation>Abrirase a ligazón despois de conectarse.</translation>
    </message>
    <message>
        <source>No password found. Please enter it.</source>
        <translation type="vanished">Non hai contrasinal. Por favor escríbea.</translation>
    </message>
    <message>
        <source>No valid login QR code found.</source>
        <translation>Non te atopou código QR de conexión válido.</translation>
    </message>
</context>
<context>
    <name>LocalAccountRemoval</name>
    <message>
        <source>Remove account from this app</source>
        <translation>Eliminar conta desde esta app</translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
        <translation>A conta vai ser eliminada desta app.
O contrasinal será borrado, asegúrate de que o tes gardado ou de que te lembras del!</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>Log in</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Log in to your XMPP account</source>
        <translation>Conectar coa súa conta XMPP</translation>
    </message>
    <message>
        <source>Your Jabber-ID:</source>
        <translation type="vanished">O seu ID-Jabber:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation type="vanished">usuaria@exemplo.org</translation>
    </message>
    <message>
        <source>Your Password:</source>
        <translation type="vanished">Contrasinal:</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Conectando…</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation type="vanished">Usuario ou contrasinal non válidos.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="vanished">Non puido conectar co servidor. Por favor, comprobe a conexión a internet.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="vanished">O servidor non soporta conexións seguras.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="vanished">Fallo ao intentar conectar de xeito seguro.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your JID again.</source>
        <translation type="vanished">Non se atopou o enderezo do servidor. Comprobe o seu JID de novo.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="vanished">Non puido conectar co servidor.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="vanished">Protocolo de autenticación non soportado polo servidor.</translation>
    </message>
    <message>
        <source>An unknown error occured; see log for details.</source>
        <translation type="vanished">Aconteceu un fallo descoñecido; vexa máis detalles no rexistro.</translation>
    </message>
    <message>
        <source>Log in using a QR-Code</source>
        <translation type="vanished">Conectar usando código QR</translation>
    </message>
</context>
<context>
    <name>MediaRecorder</name>
    <message>
        <source>Default</source>
        <translation>Por omsión</translation>
    </message>
</context>
<context>
    <name>MediaUtils</name>
    <message>
        <source>Take picture</source>
        <translation>Tomar foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Gravar vídeo</translation>
    </message>
    <message>
        <source>Record voice</source>
        <translation>Gravar voz</translation>
    </message>
    <message>
        <source>Send location</source>
        <translation>Enviar localización</translation>
    </message>
    <message>
        <source>Choose file</source>
        <translation>Escoller ficheiro</translation>
    </message>
    <message>
        <source>Choose image</source>
        <translation>Escoller imaxe</translation>
    </message>
    <message>
        <source>Choose video</source>
        <translation>Escoller vídeo</translation>
    </message>
    <message>
        <source>Choose audio file</source>
        <translation>Escoller ficheiro de audio</translation>
    </message>
    <message>
        <source>Choose document</source>
        <translation>Escoller documento</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Todos os ficheiros</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imaxes</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation>Ficheiros de audio</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation>%1 (%2)</translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="vanished">Non se enviou a mensaxe, xa que non está conectada.</translation>
    </message>
    <message>
        <source>Could not correct message, as a result of not being connected.</source>
        <translation type="vanished">Non se correxiu a mensaxe, xa que non está conectada.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">Spoiler</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>Non se puido enviar a mensaxe.</translation>
    </message>
    <message>
        <source>Message correction was not successful.</source>
        <translation>Non se puido correxir a mensaxe.</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Pending</source>
        <translation>Pendente</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Delivered</source>
        <translation>Entregado</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fallo</translation>
    </message>
</context>
<context>
    <name>MultimediaSettings</name>
    <message>
        <source>Multimedia Settings</source>
        <translation>Axustes Multimedia</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation>Capturar imaxe</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation>Gravar audio</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation>Gravar vídeo</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation>Entrada de audio</translation>
    </message>
    <message>
        <source>Container</source>
        <translation>Contedor</translation>
    </message>
    <message>
        <source>Image</source>
        <translation>Imaxe</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Códec</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolución</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Calidade</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>Taxa de mostreo</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation>Taxa de marcos</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Listo</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Inicializando…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>Non dispoñible</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation>Gravando…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>En pausa</translation>
    </message>
</context>
<context>
    <name>MultimediaSettingsPage</name>
    <message>
        <source>Multimedia Settings</source>
        <translation type="vanished">Axustes Multimedia</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation type="vanished">Configurar</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation type="vanished">Capturar imaxe</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation type="vanished">Gravando audio</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation type="vanished">Gravando vídeo</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="vanished">Cámara</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation type="vanished">Entrada de audio</translation>
    </message>
    <message>
        <source>Container</source>
        <translation type="vanished">Contedor</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Imaxe</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Audio</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Vídeo</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation type="vanished">Códec</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="vanished">Resolución</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="vanished">Calidade</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation type="vanished">Taxa de mostreo</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation type="vanished">Taxa de marcos</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="vanished">Listo</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation type="vanished">Inicializando…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation type="vanished">Non dispoñible</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation type="vanished">Gravando…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="vanished">En pausa</translation>
    </message>
</context>
<context>
    <name>NewMedia</name>
    <message>
        <source>Ready</source>
        <translation>Preparado</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Inicializando…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>Non dispoñible</translation>
    </message>
    <message>
        <source>Recording… %1</source>
        <translation>Gravando… %1</translation>
    </message>
    <message>
        <source>Paused %1</source>
        <translation>En pausa %1</translation>
    </message>
</context>
<context>
    <name>PasswordRemovalPage</name>
    <message>
        <source>Remove password</source>
        <translation>Eliminar contrasinal</translation>
    </message>
    <message>
        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
        <translation>Podes decidir que non se mostre o contrasinal para &lt;b&gt;%1&lt;/b&gt; como texto nunca máis ou eliminala completamente desde a transferencia da conta. Se eliminas o contrasinal completamente non poderás volver a utilizar a transferencia da conta vía escaneo sen escribir o contrasinal xa que tamén se eliminará do código QR.</translation>
    </message>
    <message>
        <source>Do not show password as text</source>
        <translation>Non mostrar o contrasinal como texto</translation>
    </message>
    <message>
        <source>Remove completely</source>
        <translation>Eliminar completamente</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Mark as read</source>
        <translation>Marcar como lido</translation>
    </message>
</context>
<context>
    <name>QmlUtils</name>
    <message>
        <source>Available</source>
        <translation>Dispoñible</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation>Libre para conversar</translation>
    </message>
    <message>
        <source>Away</source>
        <translation>Fóra</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation>Non molestar</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation>Fóra para longo</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Desconectada</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fallo</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation type="vanished">Non visible</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation>Usuario ou contrasinal non válidos.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation>Non hai conexión co servidor. Por favor, comproba a conexión a internet.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation>O servidor non soporta conexións seguras.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation>Fallo ao intentar conectar de xeito seguro.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your server name.</source>
        <translation>Non se puido resolver o enderezo do servidor. Comproba o nome do servidor.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="vanished">Non hai conexión co servidor.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation>Protocolo de autenticación non soportado polo servidor.</translation>
    </message>
    <message>
        <source>This server does not support registration.</source>
        <translation>O servidor non permite o rexistro.</translation>
    </message>
    <message>
        <source>An unknown error occured.</source>
        <translation type="vanished">Houbo un fallo descoñecido.</translation>
    </message>
    <message>
        <source>The server is offline or blocked by a firewall.</source>
        <translation>O servidor está desconectado ou bloqueado por cortalumes.</translation>
    </message>
    <message>
        <source>The connection could not be refreshed.</source>
        <translation>A conexión non se pode actualizar.</translation>
    </message>
    <message>
        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
        <translation>Non se permite o acceso a internet. Comproba a configuración de acceso a internet do sistema.</translation>
    </message>
</context>
<context>
    <name>QrCodeGenerator</name>
    <message>
        <source>Generating the QR code failed: %1</source>
        <translation>Fallou a creación do código QR: %1</translation>
    </message>
</context>
<context>
    <name>QrCodeScannerPage</name>
    <message>
        <source>Scan QR code</source>
        <translation>Escanear código QR</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation>Non hai cámara dispoñible.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation>A cámara está ocupada.
Pecha outras aplicacións que a estén utilizando.</translation>
    </message>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation>O formato de cámara &apos;%1&apos; non está soportado.</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Conectando…</translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation>Escanea o código QR desde o outro dispositivo para transferir a conta.</translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation>Mostrar explicación</translation>
    </message>
    <message>
        <source>Scan</source>
        <translation>Escanear</translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation>Continuar sen código QR</translation>
    </message>
</context>
<context>
    <name>RegistrationLoginDecisionPage</name>
    <message>
        <source>Set up</source>
        <translation>Axustar</translation>
    </message>
    <message>
        <source>Register a new account</source>
        <translation>Rexistrar unha nova conta</translation>
    </message>
    <message>
        <source>Use an existing account</source>
        <translation>Usar unha conta existente</translation>
    </message>
</context>
<context>
    <name>RegistrationManager</name>
    <message>
        <source>Password changed successfully.</source>
        <translation>Cambiou correctamente o contrasinal.</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation>Fallo no cambio de contrasinal: %1</translation>
    </message>
</context>
<context>
    <name>RemoteAccountDeletion</name>
    <message>
        <source>Delete account completely</source>
        <translation>Eliminar completamente a conta</translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation>A conta vaise eliminar completamente, tanto nesta app como no servidor.
Non poderás utilizar nunca máis a conta!</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>RosterAddContactSheet</name>
    <message>
        <source>Add new contact</source>
        <translation>Engadir novo contacto</translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation>Esto tamén enviará unha solicitude para acceder á presenza do contacto.</translation>
    </message>
    <message>
        <source>Jabber-ID:</source>
        <translation>ID-Jabber:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation>usuaria@exemplo.org</translation>
    </message>
    <message>
        <source>Nickname:</source>
        <translation>Alcume:</translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation>Mensaxe optativa:</translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation>Dígalle ao seu contacto quen é vostede.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Engadir</translation>
    </message>
</context>
<context>
    <name>RosterListItem</name>
    <message>
        <source>Error: Please check the JID.</source>
        <translation>Fallo: comprobe o JID.</translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="vanished">Dispoñible</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="vanished">Libre para conversar</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="vanished">Fóra</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="vanished">Non molestar</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="vanished">Fóra para longo</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="vanished">Desconectada</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Fallo</translation>
    </message>
</context>
<context>
    <name>RosterManager</name>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation>Non se engadiu o contacto, xa que non está conectada.</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation>Non se eliminou o contacto, xa que non está conectada.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation>Spoiler</translation>
    </message>
    <message>
        <source>Could not rename contact, as a result of not being connected.</source>
        <translation>Non se cambiou o nome do contacto, porque non está conectado.</translation>
    </message>
</context>
<context>
    <name>RosterPage</name>
    <message>
        <source>Connecting…</source>
        <translation>Conectando…</translation>
    </message>
    <message>
        <source>Contacts</source>
        <translation>Contactos</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>Engadir novo contacto</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Desconectada</translation>
    </message>
    <message>
        <source>Search contacts</source>
        <translation>Buscar contactos</translation>
    </message>
</context>
<context>
    <name>RosterRemoveContactSheet</name>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
        <translation>Desexa eliminar o contacto &lt;b&gt;%1&lt;/b&gt; da lista?</translation>
    </message>
    <message>
        <source>Delete contact</source>
        <translation>Eliminar contacto</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>RosterRenameContactSheet</name>
    <message>
        <source>Rename contact</source>
        <translation>Cambiar nome ao contacto</translation>
    </message>
    <message>
        <source>Edit name:</source>
        <translation type="vanished">Editar nome:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Cambiar nome</translation>
    </message>
</context>
<context>
    <name>SendMediaSheet</name>
    <message>
        <source>Caption</source>
        <translation>Descrición</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
</context>
<context>
    <name>ServerListModel</name>
    <message>
        <source>Custom server</source>
        <translation>Servidor personalizado</translation>
    </message>
    <message>
        <source>No limitation</source>
        <extracomment>Unlimited file size for uploading files
----------
Deletion of message history saved on server</extracomment>
        <translation>Sen límite</translation>
    </message>
    <message>
        <source>%1 days</source>
        <translation>%1 días</translation>
    </message>
</context>
<context>
    <name>SettingsContent</name>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation>Cambiar contrasinal</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation>Cambio no contrasinal da conta. Deberás volver a introducilo nos outros dispositivos.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation>Axustes Multimedia</translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation>Configurar os axustes para fotos e gravación de audio e vídeo</translation>
    </message>
    <message>
        <source>Account security</source>
        <translation>Seguridade da conta</translation>
    </message>
    <message>
        <source>configure whether this device can be used to log in on a new device</source>
        <translation>configura se queres poder usar este dispositivo para conectar noutro dispositivo</translation>
    </message>
    <message>
        <source>Remove account from Kaidan</source>
        <translation>Eliminar a conta de Kaidan</translation>
    </message>
    <message>
        <source>Remove account from this app</source>
        <translation>Eliminar a conta desta app</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation>Eliminar conta</translation>
    </message>
    <message>
        <source>Delete account from the server</source>
        <translation>Eliminar a conta do servidor</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation type="vanished">Cambiar contrasinal</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation type="vanished">Cambio no contrasinal da conta. Deberá voltar a introducilo nos outros dispositivos.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation type="vanished">Axustes Multimedia</translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation type="vanished">Configurar os axustes para fotos e gravación de audio e vídeo</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>Enjoy free communication on every device!</source>
        <translation>Desfruta da comunicación libre en todos os dispositivos!</translation>
    </message>
    <message>
        <source>Let&apos;s start</source>
        <translation>Comecemos</translation>
    </message>
</context>
<context>
    <name>SubRequestAcceptSheet</name>
    <message>
        <source>Subscription Request</source>
        <translation>Solicitude de subscrición</translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation>Recibeu unha solicitude de subscrición de &lt;b&gt;%1&lt;/b&gt;. Se acepta, a conta terá acceso ao seu estado de presenza.</translation>
    </message>
    <message>
        <source>Decline</source>
        <translation>Rexeitar</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>UploadManager</name>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation>Non se enviou o ficheiro, xa que non está conectada.</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Ficheiro</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>Non se puido enviar a mensaxe.</translation>
    </message>
</context>
<context>
    <name>UserProfilePage</name>
    <message>
        <source>Profile</source>
        <translation>Perfil</translation>
    </message>
</context>
<context>
    <name>VCardModel</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Alcume</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Correo-e</translation>
    </message>
    <message>
        <source>Birthday</source>
        <translation>Aniversario</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Sitio web</translation>
    </message>
</context>
</TS>
